==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/mk.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Сториџот не е валиден",
    "Unknown error" : "Непозната грешка",
    "All files" : "Сите датотеки",
    "Saved" : "Снимено",
    "Home" : "Дома",
    "Close" : "Затвори",
    "Favorites" : "Омилени",
    "Upload cancelled." : "Преземањето е прекинато.",
    "Uploading..." : "Подигнувам...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Подигање на датотека е во тек. Напуштење на страницата ќе го прекине.",
    "Actions" : "Акции",
    "Download" : "Преземи",
    "Rename" : "Преименувај",
    "Delete" : "Избриши",
    "Unshare" : "Не споделувај",
    "Files" : "Датотеки",
    "Details" : "Детали:",
    "Select" : "Избери",
    "Pending" : "Чека",
    "Invalid path" : "Грешна патека",
    "This operation is forbidden" : "Операцијата не е дозволена",
    "Name" : "Име",
    "Size" : "Големина",
    "Modified" : "Променето",
    "{dirs} and {files}" : "{dirs} и {files}",
    "New" : "Ново",
    "File name cannot be empty." : "Името на датотеката не може да биде празно.",
    "Your storage is full, files can not be updated or synced anymore!" : "Вашиот сториџ е полн, датотеките веќе не можат да се освежуваат или синхронизираат!",
    "Your storage is almost full ({usedSpacePercent}%)" : "Вашиот сториџ е скоро полн ({usedSpacePercent}%)",
    "Path" : "Патека",
    "Favorited" : "Омилени",
    "Favorite" : "Омилен",
    "Folder" : "Папка",
    "New folder" : "Нова папка",
    "{newname} already exists" : "{newname} веќе постои",
    "Upload" : "Подигни",
    "An error occurred while trying to update the tags" : "Се случи грешка додека се обидувавте да ги освежите таговите",
    "You created %1$s" : "Вие креиравте %1$s",
    "%2$s created %1$s" : "%2$s креирано %1$s",
    "You changed %1$s" : "Вие изменивте %1$s",
    "%2$s changed %1$s" : "%2$s променето %1$s",
    "You deleted %1$s" : "Вие избришавте %1$s",
    "%2$s deleted %1$s" : "%2$s избришани %1$s",
    "Changed by %2$s" : "Променето од %2$s",
    "Deleted by %2$s" : "Избришано од %2$s",
    "Restored by %2$s" : "Повратено од %2$s",
    "Upload (max. %s)" : "Префрлање (макс. %s)",
    "File handling" : "Ракување со датотеки",
    "Maximum upload size" : "Максимална големина за подигање",
    "max. possible: " : "макс. можно:",
    "Save" : "Сними",
    "Missing permissions to edit from here." : "Недостасуваат пермисии за да уредувате од тука",
    "Settings" : "Подесувања",
    "WebDAV" : "WebDAV",
    "No files in here" : "Тука нема датотеки",
    "No entries found in this folder" : "Нема ништо во оваа папка",
    "Select all" : "Избери се",
    "Upload too large" : "Фајлот кој се вчитува е преголем",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Датотеките кои се обидувате да ги подигнете ја надминуваат максималната големина за подигнување датотеки на овој сервер.",
    "Files and folders you mark as favorite will show up here" : "Датотеките и папките кои ќе ги означите како чести, ќе се појават тука",
    "Text file" : "Текстуална датотека",
    "New text file.txt" : "Нова текстуална датотека file.txt",
    "File could not be found" : "Датотеката не е пронајдена",
    "Target folder does not exist any more" : "Директориумот не постои повеќе",
    "This directory is unavailable, please check the logs or contact the administrator" : "Овој директориум е недостапен, ве молиме проверете ги логовите или контактирајте со администраторот",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Приватен линк: Само луѓето кои имаат пристап до датотеката/папката можат да го користат. Користете го како врска за себе или да го пратите на друг за да ги прикажете сите споделени податоци",
    "Show hidden files" : "Прикажи сокриени датотеки",
    "No favorites" : "Нема омилени",
    "Storage is temporarily not available" : "Складот е привремено недостапен",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Нема доволно простор, вие прикачувате {size1} а расположлив простор е {size2} ",
    "Disconnect storage" : "Прекини врска",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неможе да се прикачи {filename} Бидејќи е директориум или големината е 0 бајти",
    "Unable to determine date" : "Не може да се одреди датум",
    "You don’t have permission to upload or create files here" : "Немате дозвола да прикачувате или креирате датотеки овде",
    "You restored %1$s" : "Вративте %1$s",
    "Processing files..." : "Обработка на датотеките...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} од {totalSize} ({bitrate})",
    "{newName} already exists" : "{newName} веќе постои",
    "%1$s was created in a public folder" : "%1$s е криран во јавен директориум",
    "No entries in this folder match {filter}" : "Ниту една ставка во оваа папка не одговара на {filter}",
    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "Ограничете известувања за креирање и промени на вашите  <strong>омилени датотеки</strong>",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Немате дозволи за пристап до оваа датотека/директориум - Ве молиме контактирајте го сопственикот за да го сподели со вас.",
    "Error when assembling chunks, status code {status}" : "Грешка при составување на парчиња, статусен код {status}",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Складот на {owner} е речиси целосно искористен ({usedSpacePercent}%)",
    "Not enough free space" : "Нема доволно простор",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Складoт на {owner} е полн, датотеките не можат да се ажурираат или синхронизираат повеќе!",
    "A new file or folder has been <strong>created</strong>" : "Нова датотека или директориум е <strong>креиран</strong>",
    "A file or folder has been <strong>changed</strong>" : "Датотека или директориум е <strong>изменет</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Датотека или директоиум се <strong>избришани</strong>",
    "A file or folder has been <strong>restored</strong>" : "Датотека или директоиум се <strong>вратени</strong>",
    "%2$s restored %1$s" : "%2$s врати %1$s",
    "Upload some content or sync with your devices!" : "Прикачете некоја содржина или синхронизирајте со вашите уреди!",
    "Unknown user" : "Непознат корисник",
    "The file {file} is currently locked, please try again later" : "Датотеката {file} е моментално заклучена, Обидете се повторно",
    "Lock status" : "Статус на заклучување",
    "This resource is locked. Click to see more details." : "Ресурсот е заклучен. Кликни за повеќе детали.",
    "{owner} has locked this resource via {path}" : "{owner} го заклучи овој ресурс преку {path}",
    "Could not unlock, please contact the lock owner {owner}" : "Неможе да се одклучи, контактирајте го сопственикот {owner}",
    "Unlock failed with status {status}" : "Неуспешно одклучување со статус {status}",
    "Locks" : "Заклучувања",
    "Resource is not locked" : "Ресурсот не е заклучен"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/mk.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Складот е привремено недостапен",
    "Storage invalid" : "Складиштето не е валидно",
    "Unknown error" : "Непозната грешка",
    "All files" : "Сите датотеки",
    "File could not be found" : "Датотеката не е пронајдена",
    "Home" : "Дома",
    "Close" : "Затвори",
    "Favorites" : "Омилени",
    "Upload timeout for file \"{file}\"" : "Истече времето за прикачување на датотеката \"{file}\"",
    "Unknown error \"{error}\" uploading file \"{file}\"" : "Непозната грешка \"{error}\" при прикачување на датотеката \"{file}\"",
    "Could not create folder \"{dir}\"" : "Неможе да се креира директориум \"{dir}\"",
    "Upload cancelled." : "Преземањето е прекинато.",
    "The file {file} already exists" : "Датотеката {file} веќе постои",
    "Processing files..." : "Обработка на датотеките...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неможе да се прикачи {filename} Бидејќи е директориум или големината е 0 бајти",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Нема доволно простор, вие прикачувате {size1} а расположлив простор е {size2} ",
    "Target folder \"{dir}\" does not exist any more" : "Директориумот \"{dir}\" не постои повеќе",
    "Target folder does not exist any more" : "Директориумот не постои повеќе",
    "The file {file} is currently locked, please try again later" : "Датотеката {file} е моментално заклучена, Обидете се повторно",
    "Not enough free space" : "Нема доволно простор",
    "Uploading..." : "Подигнувам...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} од {totalSize} ({bitrate})",
    "Error when assembling chunks, status code {status}" : "Грешка при составување на парчиња, статусен код {status}",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Подигање на датотека е во тек. Напуштење на страницата ќе го прекине.",
    "Actions" : "Акции",
    "Download" : "Преземи",
    "Rename" : "Преименувај",
    "Delete" : "Избриши",
    "Disconnect storage" : "Прекини врска",
    "Unshare" : "Не споделувај",
    "Could not load info for file \"{file}\"" : "Не можам да вчитам информации за датотеката \"{file}\"",
    "Files" : "Датотеки",
    "Details" : "Детали:",
    "Select" : "Избери",
    "Pending" : "Во очекување",
    "Unable to determine date" : "Не може да се одреди датум",
    "Invalid path" : "Грешна патека",
    "This operation is forbidden" : "Операцијата не е дозволена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Овој директориум е недостапен, ве молиме проверете ги логовите или контактирајте со администраторот",
    "group" : "група",
    "Remote share" : "Оддалечено споделување",
    "Could not move \"{file}\", target exists" : "Не може да се премести \"{file}\", веќе постои",
    "Could not move \"{file}\" because either the file or the target are locked." : "Неможе да се премести \"{file}\" бидејќи датотеката или директориумот моментално е заклучен.",
    "Could not move \"{file}\": {message}" : "Неможе да се премести \"{file}\": {message}",
    "Could not move \"{file}\"" : "Не може да се премести \"{file}\"",
    "{newName} already exists" : "{newName} веќе постои",
    "Could not rename \"{fileName}\", it does not exist any more" : "Не можеше да се преименува \"{fileName}\", не постои повеќе",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{targetName}\" веќе се користи во папката \"{dir}\". Ве молиме изберете друго име.",
    "The file \"{fileName}\" is locked and can not be renamed." : "Датотеката \"{fileName}\" е заклучена и немеже да се промени името.",
    "Could not rename \"{fileName}\"" : "Не можеше да се преименува \"{fileName}\"",
    "Could not create file \"{file}\"" : "Не може да се креира датотека \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Не може да се создаде датотека \"{file}\" бидејќи веќе постои",
    "Could not create folder \"{dir}\" because it already exists" : "Не можам да креирам папка \"{dir}\" затоа што веќе постои",
    "The file \"{fileName}\" is locked and cannot be deleted." : "Датотеката \"{fileName}\" е заклучена и неможе да се избрише.",
    "Error deleting file \"{fileName}\"." : "Грешка при бришење на датотеката \"{fileName}\".",
    "No entries in this folder match {filter}" : "Ниту една ставка во оваа папка не одговара на {filter}",
    "Name" : "Име",
    "Size" : "Големина",
    "Modified" : "Променето",
    "_%n folder_::_%n folders_" : ["%n директориум","%n директориуми"],
    "_%n file_::_%n files_" : ["%n датотека","%n датотеки"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["вклучувајќи %n скриен","вклучувајќи%n скриени"],
    "You don’t have permission to upload or create files here" : "Немате дозвола да прикачувате или креирате датотеки овде",
    "_Uploading %n file_::_Uploading %n files_" : ["Се прикачува %n датотека","Се прикачуваат %n датотеки"],
    "New" : "Ново",
    "Unknown user" : "Непознат корисник",
    "Lock status" : "Статус на заклучување",
    "This resource is locked. Click to see more details." : "Ресурсот е заклучен. Кликни за повеќе детали.",
    "\"{name}\" is an invalid file name." : "\"{name}\" е невалидно име за датотека.",
    "File name cannot be empty." : "Името на датотеката не може да биде празно.",
    "File name cannot contain \"/\"." : "Името на датотеката несмее да содржи \"/\".",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" е забранет вид на датотека/екстензија.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Складoт на {owner} е полн, датотеките не можат да се ажурираат или синхронизираат повеќе!",
    "Your storage is full, files can not be updated or synced anymore!" : "Вашиот сториџ е полн, датотеките веќе не можат да се освежуваат или синхронизираат!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Складот на {owner} е речиси целосно искористен ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Вашиот сториџ е скоро полн ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["matches '{filter}'","match '{filter}'"],
    "{owner} has locked this resource via {path}" : "{owner} го заклучи овој ресурс преку {path}",
    "Could not unlock, please contact the lock owner {owner}" : "Неможе да се одклучи, контактирајте го сопственикот {owner}",
    "Unlock failed with status {status}" : "Неуспешно одклучување со статус {status}",
    "Locks" : "Заклучувања",
    "Resource is not locked" : "Ресурсот не е заклучен",
    "Path" : "Патека",
    "_%n byte_::_%n bytes_" : ["бајт","%n бајти"],
    "Favorited" : "Омилени",
    "Favorite" : "Омилен",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Приватен линк: Само луѓето кои имаат пристап до датотеката/папката можат да го користат. Користете го како врска за себе или да го пратите на друг за да ги прикажете сите споделени податоци",
    "Folder" : "Папка",
    "New folder" : "Нова папка",
    "{newname} already exists" : "{newname} веќе постои",
    "Upload" : "Подигни",
    "An error occurred while trying to update the tags" : "Се случи грешка додека се обидувавте да ги освежите таговите",
    "A new file or folder has been <strong>created</strong>" : "Нова датотека или директориум е <strong>креиран</strong>",
    "A file or folder has been <strong>changed</strong>" : "Датотека или директориум е <strong>изменет</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ограничете известувања за креирање и промени на вашите <strong>омилени датотеки</strong> <em>(само во стримот)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Датотека или директоиум се <strong>избришани</strong>",
    "A file or folder has been <strong>restored</strong>" : "Датотека или директоиум се <strong>вратени</strong>",
    "You created %1$s" : "Вие го креиравте %1$s",
    "%2$s created %1$s" : "%2$s креираше %1$s",
    "%1$s was created in a public folder" : "%1$s е криран во јавен директориум",
    "You changed %1$s" : "Вие го променивте %1$s",
    "%2$s changed %1$s" : "%2$s измени %1$s",
    "You deleted %1$s" : "Вие го избришавте %1$s",
    "%2$s deleted %1$s" : "%2$s избриша %1$s",
    "You restored %1$s" : "Вративте %1$s",
    "%2$s restored %1$s" : "%2$s врати %1$s",
    "Changed by %2$s" : "Променето од %2$s",
    "Deleted by %2$s" : "Избришано од %2$s",
    "Restored by %2$s" : "Повратено од %2$s",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Немате дозволи за пристап до оваа датотека/директориум - Ве молиме контактирајте го сопственикот за да го сподели со вас.",
    "Upload (max. %s)" : "Префрлање (макс. %s)",
    "Settings" : "Подесувања",
    "Show hidden files" : "Прикажи сокриени датотеки",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Користи ја оваа адреса за <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">пристап преку WebDAV</a>",
    "No files in here" : "Тука нема датотеки",
    "Upload some content or sync with your devices!" : "Прикачете некоја содржина или синхронизирајте со вашите уреди!",
    "No entries found in this folder" : "Нема ништо во оваа папка",
    "Select all" : "Избери се",
    "Upload too large" : "Фајлот кој се вчитува е преголем",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Датотеките кои се обидувате да ги подигнете ја надминуваат максималната големина за подигнување датотеки на овој сервер.",
    "No favorites" : "Нема омилени",
    "Files and folders you mark as favorite will show up here" : "Датотеките и папките кои ќе ги означите како фаворити, ќе се појават тука",
    "Text file" : "Текстуална датотека",
    "New text file.txt" : "Нова текстуална датотека file.txt"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
